@@ -624,23 +624,23 @@ class BaseExperiment:
             ckpt_name = model_metadata + ".ckpt"
         else:
             raise NotImplementedError("Astrape only supports variants of sklearn and pl.LightningModule.")
-        checkpoint_path = self.log_path + "/checkpoints/" + model.__class__.__name__ + "/" + model_metadata
+        
+        # saving model checkpoints
+        checkpoint_path = f"{self.log_path}/checkpoints/{model.__class__.__name__}/{model_metadata}"
         self._create_folder(checkpoint_path)
         ckpt_version = len(os.listdir(checkpoint_path))
-        ckpt_path = checkpoint_path +"/" + ckpt_name + f"version_{ckpt_version}"
-        
+        ckpt_path = f"{checkpoint_path}/version_{ckpt_version}/{ckpt_name}"
+
         if isinstance(model, BaseEstimator):
             pickle.dump(model, open(ckpt_path, 'wb'))
         elif isinstance(model, pl.LightningModule):
             trainer.save_checkpoint(ckpt_path)
-
-
-        metadata_dir = self.log_path + "/jsonlogs/" + model.__class__.__name__ + "/" + model_metadata
+        metadata_dir = f"{self.log_path}/jsonlogs/{model.__class__.__name__}/{model_metadata}"
         self._create_folder(metadata_dir)
         jsonlog_version = len(os.listdir(metadata_dir))
         
-        
-        self._create_folder(metadata_dir+f"/version_{jsonlog_version}")
+        # saving results 
+        self._create_folder(f"{metadata_dir}/version_{jsonlog_version}")
         if isinstance(model, BaseEstimator):
             tensorboard_logdir = self.logger.get_logdir()
         else:
